import aiosched
from catch import child
from debugger import Debugger


async def main(children: list[tuple[str, int]]):
    try:
        async with aiosched.with_context() as ctx:
            print("[main] Spawning children")
            for name, delay in children:
                await ctx.spawn(child, name, delay)
            print(f"[main] Spawned {len(ctx.tasks)} children")
            before = aiosched.clock()
    except BaseException as err:
        print(f"[main] Child raised an exception -> {type(err).__name__}: {err}")
    print(f"[main] Children exited in {aiosched.clock() - before:.2f} seconds")


if __name__ == "__main__":
    aiosched.run(main, [("first", 1), ("second", 2), ("third", 3)], debugger=None)
